/*
 * Copyright 2012-2013 Ray Holder
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.rholder.fauxflake;

import com.github.rholder.fauxflake.api.EncodingProvider;
import com.github.rholder.fauxflake.api.Id;

/**
 * Use an {@link EncodingProvider} to back an implementation of the {@link Id}
 * interface.
 */
public class EncodedId implements Id {

    private EncodingProvider encodingProvider;
    private long time;
    private int sequence;

    public EncodedId(EncodingProvider encodingProvider, long time, int sequence) {
        this.encodingProvider = encodingProvider;
        this.time = time;
        this.sequence = sequence;
    }

    @Override
    public long asLong() {
        return encodingProvider.encodeAsLong(time, sequence);
    }

    @Override
    public byte[] asBytes() {
        return encodingProvider.encodeAsBytes(time, sequence);
    }

    @Override
    public String asString() {
        return encodingProvider.encodeAsString(time, sequence);
    }
}